/*
 * Copyright (c) 2021 The Hydra authors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package be.ugent.zeus.hydra.feed.commands;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import java.util.Objects;

import be.ugent.zeus.hydra.feed.cards.Card;

/**
 * @author Niko Strijbol
 */
public final class CommandResult {

    @Card.Type
    private final int cardType;
    @Nullable
    private final FeedCommand command;

    private CommandResult(@Card.Type int cardType, @Nullable FeedCommand command) {
        this.cardType = cardType;
        this.command = command;
    }

    public static CommandResult forUndo(@Card.Type int cardType) {
        return new CommandResult(cardType, null);
    }

    public static CommandResult forExecute(FeedCommand command, @Card.Type int cardType) {
        return new CommandResult(cardType, command);
    }

    @Card.Type
    public int cardType() {
        return cardType;
    }

    public boolean wasUndo() {
        return command == null;
    }

    @NonNull
    public FeedCommand getCommand() {
        return Objects.requireNonNull(command);
    }
}